@@ -29,7 +29,7 @@ nrow.disk.frame <- function(df, ...) {
   stopifnot(is_ready(df))
   path1 <- attr(df,"path", exact=TRUE)
   if(dir.exists(path1)) {
-    path2 <- list.files(path1,full.names = TRUE)
+    path2 <- list.files(path1, full.names = TRUE, recursive=TRUE, pattern = "fst")
     if(length(path2) == 0) {
       return(0)
     }
